@@ -1,10 +1,10 @@
 # Copyright 2001-2010 by Roger Bivand 
 #
 
-lm.morantest <- function(model, listw, zero.policy=NULL, 
+lm.morantest <- function(model, listw, zero.policy=attr(listw, "zero.policy"), 
 	    alternative = "greater", spChk=NULL, resfun=weighted.residuals,		    naSubset=TRUE) {
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
+            zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
 	alternative <- match.arg(alternative, c("greater", "less", "two.sided"))
 	listw_name <- deparse(substitute(listw))
@@ -72,9 +72,9 @@ lm.morantest <- function(model, listw, zero.policy=NULL,
     	attr(statistic, "names") <- "Moran I statistic standard deviate"
     	p.value <- pv
     	estimate <- c(I, EI, VI)
-    	attr(estimate, "names") <- c("Observed Moran's I", "Expectation",
+    	attr(estimate, "names") <- c("Observed Moran I", "Expectation",
 	    "Variance")
-    	method <- "Global Moran's I for regression residuals"
+    	method <- "Global Moran I for regression residuals"
     	data.name <- paste("\n", paste(strwrap(paste("model: ",
 	    gsub("[[:space:]]+", " ", 
 	    paste(deparse(model$call), sep="", collapse="")))), collapse="\n"),
